@@ -32,6 +32,7 @@ class WebCoverageService_1_0_0(WCSBase):
     """Abstraction for OGC Web Coverage Service (WCS), version 1.0.0
     Implements IWebCoverageService.
     """
+
     def __getitem__(self,name):
         ''' check contents dictionary to allow dict like access to service layers'''
         if name in self.__getattribute__('contents').keys():
@@ -39,12 +40,13 @@ class WebCoverageService_1_0_0(WCSBase):
         else:
             raise KeyError("No content named %s" % name)
     
-    def __init__(self,url,xml, cookies):
+    def __init__(self,url,xml, cookies, auth=None):
+        super(WebCoverageService_1_0_0, self).__init__(auth)
         self.version='1.0.0'
         self.url = url   
         self.cookies=cookies
         # initialize from saved capability document or access the server
-        reader = WCSCapabilitiesReader(self.version, self.cookies)
+        reader = WCSCapabilitiesReader(self.version, self.cookies, self.auth)
         if xml:
             self._capabilities = reader.readString(xml)
         else:
@@ -87,8 +89,7 @@ class WebCoverageService_1_0_0(WCSBase):
         #exceptions
         self.exceptions = [f.text for f \
                 in self._capabilities.findall('Capability/Exception/Format')]
-    
-    
+
     def items(self):
         '''supports dict-like items() access'''
         items=[]
@@ -161,12 +162,8 @@ class WebCoverageService_1_0_0(WCSBase):
         if log.isEnabledFor(logging.DEBUG):
             log.debug('WCS 1.0.0 DEBUG: Second part of URL: %s'%data)
         
-        
-        u=openURL(base_url, data, method, self.cookies)
-
+        u = openURL(base_url, data, method, self.cookies, auth=self.auth)
         return u
-    
-
                
     def getOperationByName(self, name):
         """Return a named operation item."""
