@@ -1,6 +1,6 @@
 import cgi
 from owslib.etree import etree
-from owslib.util import openURL
+from owslib.util import Authentication, openURL
 
 try:
     from urllib import urlencode
@@ -13,11 +13,15 @@ class WFSCapabilitiesReader(object):
     """Read and parse capabilities document into a lxml.etree infoset
     """
 
-    def __init__(self, version='1.0', username=None, password=None):
+    def __init__(self, version='1.0', username=None, password=None, auth=None):
         """Initialize"""
+        if auth:
+            if username:
+                auth.username = username
+            if password:
+                auth.password = password
+        self.auth = auth or Authentication(username, password)
         self.version = version
-        self.username = username
-        self.password = password
         self._infoset = None
 
     def capabilities_url(self, service_url):
@@ -51,8 +55,7 @@ class WFSCapabilitiesReader(object):
             A timeout value (in seconds) for the request.
         """
         request = self.capabilities_url(url)
-        u = openURL(request, timeout=timeout,
-                    username=self.username, password=self.password)
+        u = openURL(request, timeout=timeout, auth=self.auth)
         return etree.fromstring(u.read())
 
     def readString(self, st):
@@ -67,5 +70,9 @@ class WFSCapabilitiesReader(object):
 
 
 class AbstractContentMetadata(object):
+    
+    def __init__(self, auth=None):
+        self.auth = auth or Authentication()
+        
     def get_metadata(self):
-        return [m['metadata'] for m in self.metadataUrls if m.get('metadata', None) is not None]
\ No newline at end of file
+        return [m['metadata'] for m in self.metadataUrls if m.get('metadata', None) is not None]
